<?php
/**
 * Clase IngresoDiversosBL
 *
 * @package    
 * @subpackage 
 * @author     IngresoDiversosBL
 * @version    SVN: $Id: IngresoDiversosBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class IngresoDiversosBL{
    
  /**
  * 
  *
  * @param $o_IngresoDiversosBean, objeto de tipo IngresoDiversos 
  * @return Boolean
  */
  public function busquedaIngresoDiversos(IngresoDiversosBean $o_IngresoDiversosBean){
    
    $o_IngresoDiversosDP = new IngresoDiversosDP($o_IngresoDiversosBean);
    if($o_IngresoDiversosBean->getIdIngreso()){
      return $o_IngresoDiversosDP->selectByPk();
    }else{
      return $o_IngresoDiversosDP->select();
    }
    
  }
  
  public function busquedaIngresoDiversosResulset(IngresoDiversosBean $o_IngresoDiversosBean){
    
    $o_IngresoDiversosDP = new IngresoDiversosDP($o_IngresoDiversosBean);
    return $o_IngresoDiversosDP->selectResultset();
        
  }
  
  public function insertarIngresoDiversos(IngresoDiversosBean $o_IngresoDiversosBean){
    
    $o_IngresoDiversosCT = new IngresoDiversosCT();
    return $o_IngresoDiversosCT->guardar($o_IngresoDiversosBean);
    
  }
  public function modificarIngresoDiversos(IngresoDiversosBean $o_IngresoDiversosBean){
      $o_IngresoDiversosCT = new IngresoDiversosCT();
      return $o_IngresoDiversosCT->modificar($o_IngresoDiversosBean);
  }
  /**
	* Función que retorna un objeto IngresoDiversos o una lista de Objetos de IngresoDiversos,
	* dependiendo del parametro que se le envia si este contiene o no el Id de IngresoDiversos
	*
	* @param $o_IngresoDiversosBean, es un objeto de tipo IngresoDiversos
	* @return Object
	*/
	
  
  public function eliminarIngresoDiversos(IngresoDiversosBean $o_IngresoDiversosBean){
    $o_IngresoDiversosCT = new IngresoDiversosCT();
    return $o_IngresoDiversosCT->eliminar($o_IngresoDiversosBean);
    
  }
  
  public function getCountResult(IngresoDiversosBean $o_IngresoDiversosBean){
    $o_IngresoDiversosCT = new IngresoDiversosCT();
    return $o_IngresoDiversosCT->totalRegistros($o_IngresoDiversosBean);
  }
  
}

