<?php

class IngresoDiversosSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertIngresoDiversos(){
    
    $o_IngresoDiversosBL = new IngresoDiversosBL();
    return $o_IngresoDiversosBL->insertarIngresoDiversos($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
   
  public function eliminarIngresoDiversos(){
    
    $o_IngresoDiversosBL = new IngresoDiversosBL();
    return $o_IngresoDiversosBL->eliminarIngresoDiversos($this->getObjParamBean());
    
  }
  
  public function actualizarIngresoDiversos(){
    
    $o_IngresoDiversosBL = new IngresoDiversosBL();
    return $o_IngresoDiversosBL->modificarIngresoDiversos($this->getObjParamBean());
    
  }
  
  public function getIngresoDiversos(){
  
    $o_IngresoDiversosBL = new IngresoDiversosBL();
    return $o_IngresoDiversosBL->busquedaIngresoDiversos($this->getObjParamBean());
  
  }
   
  public function getColaborador(){
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->busquedaColaborador(new ColaboradorBean());
    
  }
  public function getGrado(){
    $o_GradoBL = new GradoBL();
    return $o_GradoBL->busquedaGrado(new GradoBean());
    
  }
  public function getSucursal(){
    
    $o_SucursalBL = new SucursalBL();
    return $o_SucursalBL->busquedaSucursal(new SucursalBean());
  }
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }

}